@@ -1,6 +1,6 @@
 #' Plots a Julia Set for a tree
 #'
-#' Finds the Julia Set for the complex polynomial of a tree and plots in a square image.
+#' Finds the Julia Set for the y evaluated polynomial of a tree and plots in a square image.
 #'
 #' @param tree phylo object
 #' @param pixelLength number of pixels on one side of the image
@@ -8,6 +8,7 @@
 #' @param maxZ the max value for the real and imaginary axis
 #' @param maxIter maximum count for iterations
 #' @param col colours to be used for the image
+#' @param y the y value to evaluate the polynomial at
 #' @useDynLib treenomial
 #' @importFrom Rcpp sourceCpp
 #' @importFrom grDevices colorRampPalette
@@ -16,16 +17,16 @@
 #'
 #' library(treenomial)
 #' library(ape)
-#' treeJuliaSet(stree(5,type = "right"))
+#' treeJuliaSet(stree(5,type = "right"), y = 1+1i)
 #'
 #' @export
-treeJuliaSet <- function(tree, pixelLength = 700, center = 0, maxZ = 2, maxIter = 100, col = c("white", colorRampPalette(c("dodgerblue4", "lightblue"))(98) , "black")) {
+treeJuliaSet <- function(tree, pixelLength = 700, center = 0, maxZ = 2, maxIter = 100, col = c("white", colorRampPalette(c("dodgerblue4", "lightblue"))(98) , "black"), y){
   oldpar <- par(no.readonly =TRUE)
   on.exit(par(oldpar))
 
   par(mar = c(1,1,1,1))
 
-  coeff <- treeToPoly(tree, type = "complex", numThreads = 0)
+  coeff <- treeToPoly(tree, type = "yEvaluated", y = y, numThreads = 0)
 
   res <- juliaSet(coeffs = coeff, pixelLength = pixelLength, center = center, maxZ = maxZ, maxIter = maxIter)
 
